@@ -11,7 +11,7 @@ use JIRACLI qw/get_credentials/;
 
 my ($opt, $usage) = describe_options(
     '%c %o',
-    ['jiraurl=s',   "JIRA server base URL", {default => 'https://jira.cpqd.com.br'}],
+    ['jiraurl=s',   "JIRA server base URL", {required => 1}],
     ['jql=s',  "JQL query expression", {required => 1}],
     ['help|h',      "Print usage message and exit"],
     {show_defaults => 1},
@@ -50,6 +50,7 @@ Reporter: $fields->{reporter}{name}
 EOS
 }
 
+
 __END__
 
 =head1 NAME
@@ -60,7 +61,6 @@ search.pl - Search JIRA issues by a JQL filter
 
   search.pl [-hn] [long options...]
     --jiraurl STR   JIRA server base URL
-                    (default value: https://jira.cpqd.com.br)
     --jql STR       JQL query expression
     -h --help       Print usage message and exit
 
@@ -92,7 +92,7 @@ See the L<JIRACLI> documentation.
 
 =head1 COPYRIGHT
 
-Copyright 2016 CPQD.
+Copyright 2016-2022 CPQD.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
