@@ -1,6 +1,6 @@
 package JIRA::REST;
 # ABSTRACT: Thin wrapper around Jira's REST API
-$JIRA::REST::VERSION = '0.023';
+$JIRA::REST::VERSION = '0.024';
 use 5.016;
 use utf8;
 use warnings;
@@ -222,31 +222,14 @@ sub _error {
     if ($type =~ m:text/plain:i) {
         $msg .= $content;
     } elsif ($type =~ m:application/json:) {
-        my $error = $self->{json}->decode($content);
-        if (ref $error eq 'HASH') {
-            # Jira errors may be laid out in all sorts of ways. You have to
-            # look them up from the scant documentation at
-            # https://docs.atlassian.com/jira/REST/latest/.
-
-            # /issue/bulk tucks the errors one level down, inside the
-            # 'elementErrors' hash.
-            $error = $error->{elementErrors} if exists $error->{elementErrors};
-
-            # Some methods tuck the errors in the 'errorMessages' array.
-            if (my $errorMessages = $error->{errorMessages}) {
-                $msg .= "- $_\n" foreach @$errorMessages;
-            }
-
-            # And some tuck them in the 'errors' hash.
-            if (my $errors = $error->{errors}) {
-                $msg .= "- [$_] $errors->{$_}\n" foreach sort keys %$errors;
-            }
-
-            # some give us a single message in 'errorMessage'
-            $msg .= $error->{errorMessage} . qq{\n} if $error->{errorMessage};
-        } else {
-            $msg .= $content;
-        }
+        # Jira errors may be laid out in all sorts of ways. You have to look
+        # them up from the scant documentation at
+        # https://docs.atlassian.com/jira/REST/latest/.  Previously, I tried to
+        # grok the actual message inside this JSON structure but I failed
+        # miserably. So, I decided to give up and simply show the actual JSON
+        # string as a message. It won't be as readable, but it will be complete
+        # and correct!
+        $msg .= $content;
     } elsif ($type =~ m:text/html:i && eval {require HTML::TreeBuilder}) {
         $msg .= HTML::TreeBuilder->new_from_content($content)->as_text;
     } elsif ($type =~ m:^(text/|application|xml):i) {
@@ -317,9 +300,6 @@ sub DELETE {
 sub PUT {
     my ($self, $path, $query, $value, $headers) = @_;
 
-    defined $value
-        or croak $self->_error("PUT method's 'value' argument is undefined.");
-
     $path = $self->_build_path($path, $query);
 
     $headers                   ||= {};
@@ -333,9 +313,6 @@ sub PUT {
 sub POST {
     my ($self, $path, $query, $value, $headers) = @_;
 
-    defined $value
-        or croak $self->_error("POST method's 'value' argument is undefined.");
-
     $path = $self->_build_path($path, $query);
 
     $headers                   ||= {};
@@ -430,7 +407,7 @@ JIRA::REST - Thin wrapper around Jira's REST API
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -855,7 +832,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2024 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
